@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2007 Urs Wolfer <uwolfer @ kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2007 Urs Wolfer <uwolfer@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include <QApplication>
@@ -34,7 +23,8 @@ public:
 
         KTitleWidget *titleWidget = new KTitleWidget(this);
         titleWidget->setText(QStringLiteral("Title"));
-        titleWidget->setPixmap(QIcon::fromTheme(QStringLiteral("screen")).pixmap(22, 22), KTitleWidget::ImageLeft);
+        titleWidget->setIconSize(QSize(22, 22));
+        titleWidget->setIcon(QIcon::fromTheme(QStringLiteral("kde")), KTitleWidget::ImageLeft);
 
         mainLayout->addWidget(titleWidget);
 
@@ -67,7 +57,6 @@ public:
 int main(int argc, char **argv)
 {
     QApplication::setApplicationName(QStringLiteral("ktitlewidgettest"));
-    QApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
     QApplication app(argc, argv);
 
     KTitleWidgetTestWidget *mainWidget = new KTitleWidgetTestWidget;
